//
//  ViewController.swift
//  ARPhysics
//
//  Created by kunii on 2019/01/20.
//  Copyright © 2019 Takahiro Kunii. All rights reserved.
//

import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate {

    @IBOutlet var sceneView: ARSCNView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // Set the view's delegate
        sceneView.delegate = self
        
        // Show statistics such as fps and timing information
        sceneView.showsStatistics = true
        
        // Create a new scene
        let scene = SCNScene(named: "art.scnassets/ship.scn")!
        phygicsLab(scene:scene)
        
        // Set the scene to the view
        sceneView.scene = scene
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        // Create a session configuration
        let configuration = ARWorldTrackingConfiguration()

        // Run the view's session
        sceneView.session.run(configuration)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
        // Pause the view's session
        sceneView.session.pause()
    }

    // MARK: - ARSCNViewDelegate
    
/*
    // Override to create and configure nodes for anchors added to the view's session.
    func renderer(_ renderer: SCNSceneRenderer, nodeFor anchor: ARAnchor) -> SCNNode? {
        let node = SCNNode()
     
        return node
    }
*/
    
    func session(_ session: ARSession, didFailWithError error: Error) {
        // Present an error message to the user
        
    }
    
    func sessionWasInterrupted(_ session: ARSession) {
        // Inform the user that the session has been interrupted, for example, by presenting an overlay
        
    }
    
    func sessionInterruptionEnded(_ session: ARSession) {
        // Reset tracking and/or remove existing anchors if consistent tracking is required
        
    }

    func phygicsLab(scene:SCNScene) {
        if let ship = scene.rootNode.childNode(withName: "ship", recursively: true) {
            //  宇宙船を動的な物理物体として設定
            ship.physicsBody = SCNPhysicsBody.dynamic()
            ship.position.z = -3
        }
        
        //  床を追加　静的な物理物体として設定
        let floorNode = SCNNode(geometry: SCNFloor())
        floorNode.physicsBody = SCNPhysicsBody.static()
        floorNode.position.y = -1
        scene.rootNode.addChildNode(floorNode)
        
        // 画面タップを見張る
        self.view.addGestureRecognizer(UITapGestureRecognizer(target: self, action: #selector(didTap)))
    }
    
    /// 画面タップされたら、宇宙船に力加える
    @objc func didTap() {
        if let ship = sceneView.scene.rootNode.childNode(withName: "ship", recursively: true) {
            ship.physicsBody?.applyForce(SCNVector3(x:0, y:8, z:0), asImpulse: true)
        }
    }
}

